import {
  WebStorage
} from "./chunk-YWADTQF4.js";

// src/hooks/use-storage.ts
import { useCallback, useEffect, useRef, useState } from "react";
var defaultStorage = new WebStorage();
function useStorage({
  key,
  initialValue,
  preprocessValue,
  storage = defaultStorage
}) {
  const storageRef = useRef(storage);
  const preprocessValueRef = useRef(preprocessValue);
  preprocessValueRef.current = preprocessValue;
  const [value, setValue] = useState(initialValue);
  useEffect(() => {
    const listener = (newValue) => {
      if (newValue === void 0) {
        setValue(void 0);
        return;
      }
      setValue(
        preprocessValueRef.current ? preprocessValueRef.current(newValue) : newValue
      );
    };
    const unsubscribe = storageRef.current.watch(key, listener);
    return () => {
      unsubscribe();
    };
  }, [key]);
  const setState = useCallback(
    async (setter) => {
      await storageRef.current.set(
        key,
        typeof setter === "function" ? setter : () => setter
      );
    },
    [key]
  );
  return [value, setState];
}

export {
  useStorage
};
