import { Storage } from '../identity/types.cjs';
import './use-visibility-detection.cjs';

type Primitives = string | number | boolean | null;
type Arr = AllowedValue[];
type Obj = {
    [key in string]: AllowedValue;
} & {
    [key in string]?: AllowedValue | undefined;
};
type AllowedValue = Primitives | Arr | Obj;
type UseStorageOptions<TValue extends AllowedValue | undefined> = {
    key: string;
    initialValue?: TValue;
    preprocessValue?: (value: TValue) => TValue;
    /**
     * @defaultValue WebStorage
     */
    storage?: Storage;
};
type Setter<TValue extends AllowedValue | undefined> = (value: TValue | ((prevState: TValue) => TValue)) => Promise<void>;
declare function useStorage<TValue extends AllowedValue | undefined>(options: UseStorageOptions<TValue>): [TValue, Setter<TValue>];

export { useStorage };
